@@ -2,15 +2,19 @@ test_that("all S3 methods have reasonable ouputs", {
   fit1 <- brms:::rename_pars(brms:::brmsfit_example1)
   fit2 <- brms:::rename_pars(brms:::brmsfit_example2)
   fit3 <- brms:::rename_pars(brms:::brmsfit_example3)
+  fit4 <- brms:::rename_pars(brms:::brmsfit_example4)
+  
   # test S3 methods in alphabetical order
   # as.data.frame
   ps <- as.data.frame(fit1)
   expect_true(is(ps, "data.frame"))
   expect_equal(dim(ps), c(Nsamples(fit1), length(parnames(fit1))))
+  
   # as.matrix
   ps <- as.matrix(fit1)
   expect_true(is(ps, "matrix"))
   expect_equal(dim(ps), c(Nsamples(fit1), length(parnames(fit1))))
+  
   # as.mcmc
   chains <- fit1$fit@sim$chains
   mc <- as.mcmc(fit1)
@@ -21,14 +25,19 @@ test_that("all S3 methods have reasonable ouputs", {
   # test assumes thin = 1
   expect_equal(dim(as.mcmc(fit1, inc_warmup = TRUE)[[1]]), 
                c(fit1$fit@sim$iter, length(parnames(fit1))))
+  
   # coef
   coef1 <- coef(fit1)
   expect_equal(dim(coef1$visit), c(4, 8))
   coef2 <- coef(fit2)
   expect_equal(dim(coef2[[2]]), c(59, 2))
   expect_equal(attr(coef2[[1]], "nlpar"), "a")
+  coef4 <- coef(fit4)
+  expect_equal(dim(coef4$subject), c(10, 8))
+  
   # family
   expect_equal(family(fit1), brmsfamily("student", link = "identity"))
+  
   # fitted
   fi <- fitted(fit1)
   expect_equal(dim(fi), c(nobs(fit1), 4))
@@ -50,6 +59,10 @@ test_that("all S3 methods have reasonable ouputs", {
   fi <- fitted(fit2, newdata = newdata,
                allow_new_levels = TRUE)
   expect_equal(dim(fi), c(2, 4))
+  
+  fi <- fitted(fit4)
+  expect_equal(dim(fi), c(nobs(fit4), 4, 4))
+  
   # fixef
   fixef1 <- fixef(fit1, estimate = c("mean", "sd"))  
   expect_equal(dimnames(fixef1), 
@@ -61,9 +74,11 @@ test_that("all S3 methods have reasonable ouputs", {
   expect_equal(dimnames(fixef2),
                list(c("a_Intercept", "a_Age", "b_Intercept", "b_Age"),
                     c("median", "5%", "95%")))
+  
   # formula
   expect_equal(formula(fit1), 
     count ~ Trt * Age + mono(Exp) + s(Age) + offset(Age) + (1 + Trt | visit))
+  
   # hypothesis
   h1 <- hypothesis(fit1, "Intercept > Trt")
   expect_equal(dim(h1$hypothesis), c(1, 6))
@@ -76,11 +91,14 @@ test_that("all S3 methods have reasonable ouputs", {
   expect_silent(p <- plot(h2, ignore_prior = TRUE, plot = FALSE))
   expect_error(hypothesis(fit1, "Intercept > x"), fixed = TRUE,
                "cannot be found in the model: \nb_x")
+  
   # omit launch_shiny
+  
   # log_lik
   expect_equal(dim(log_lik(fit1)), c(Nsamples(fit1), nobs(fit1)))
   expect_equal(dim(log_lik(fit2)), c(Nsamples(fit2), nobs(fit2)))
   expect_equal(log_lik(fit1), logLik(fit1))
+  
   # LOO
   loo1 <- SW(LOO(fit1, cores = 1))
   expect_true(is.numeric(loo1[["looic"]]))
@@ -105,6 +123,10 @@ test_that("all S3 methods have reasonable ouputs", {
   expect_true(is.numeric(loo3[["looic"]]))
   loo3 <- SW(LOO(fit3, pointwise = TRUE, cores = 1))
   expect_true(is.numeric(loo3[["looic"]]))
+  
+  loo4 <- SW(LOO(fit4, cores = 1))
+  expect_true(is.numeric(loo4[["looic"]]))
+  
   # marginal_effects (the related plot method is tested in tests.plots)
   expect_equal(nrow(marginal_effects(fit1)[[2]]), 100)
   mdata = data.frame(Age = c(-0.3, 0, 0.3), count = c(10, 20, 30), 
@@ -127,6 +149,10 @@ test_that("all S3 methods have reasonable ouputs", {
   expect_equal(nrow(marginal_effects(fit2)[[2]]), 100)
   expect_equal(nrow(marginal_effects(fit2, conditions = mdata)[[1]]),
                exp_nrow)
+  expect_warning(me4 <- marginal_effects(fit4),
+                 "Predictions are treated as continuous variables")
+  expect_true(is(me4, "brmsMarginalEffects"))
+  
   # marginal_smooths
   ms1 <- marginal_smooths(fit1)
   expect_equal(nrow(ms1[[1]]), 100)
@@ -135,13 +161,17 @@ test_that("all S3 methods have reasonable ouputs", {
                "No valid smooth terms found in the model")
   expect_error(marginal_smooths(fit2),
                "No valid smooth terms found in the model")
+  
   # model.frame
   expect_equal(model.frame(fit1), fit1$data)
+  
   # ngrps
   expect_equal(ngrps(fit1), list(visit = 4))
   expect_equal(ngrps(fit2), list(patient = 59))
+  
   # nobs
   expect_equal(nobs(fit1), nrow(epilepsy))
+  
   # parnames 
   expect_equal(parnames(fit1)[c(1, 8, 9, 13, 15, 17, 27, 35, 38, 46)],
                c("b_Intercept", "bmo_Exp", "ar[1]", "cor_visit__Intercept__Trt", 
@@ -152,7 +182,9 @@ test_that("all S3 methods have reasonable ouputs", {
                  "cor_patient__a_Intercept__b_Intercept", 
                  "r_patient__a[1,Intercept]", "r_patient__b[4,Intercept]",
                  "prior_b_a"))
+  
   # plot tested in tests.plots.R
+  
   # posterior_samples
   ps <- posterior_samples(fit1)
   expect_equal(dim(ps), c(Nsamples(fit1), length(parnames(fit1))))
@@ -160,9 +192,11 @@ test_that("all S3 methods have reasonable ouputs", {
   expect_equal(names(posterior_samples(fit1, pars = "^b_")),
                c("b_Intercept", "b_Trt", "b_Age", "b_Trt:Age", 
                  "b_sAge_1", "b_sigma_Intercept", "b_sigma_Trt"))
+  
   # posterior_predict
   expect_equal(dim(posterior_predict(fit1)), 
                c(Nsamples(fit1), nobs(fit1)))
+  
   # pp_check
   expect_true(is(pp_check(fit1), "ggplot"))
   expect_true(is(pp_check(fit1, newdata = fit1$data[1:100, ]), "ggplot"))
@@ -176,6 +210,8 @@ test_that("all S3 methods have reasonable ouputs", {
   expect_error(pp_check(fit2, "violin_grouped"), "group")
   expect_error(pp_check(fit1, "stat_grouped", group = "g"),
                "not a valid grouping factor")
+  expect_true(is(pp_check(fit4), "ggplot"))
+  
   # predict
   pred <- predict(fit1)
   expect_equal(dim(pred), c(nobs(fit1), 4))
@@ -201,15 +237,21 @@ test_that("all S3 methods have reasonable ouputs", {
   pred <- predict(fit2, newdata = newdata, 
                   allow_new_levels = TRUE)
   expect_equal(dim(pred), c(2, 4))
+  
+  pred <- predict(fit4)
+  expect_equal(dim(pred), c(nobs(fit4), 4))
   # check if grouping factors with a single level are accepted
   newdata$patient <- factor(2)
   pred <- predict(fit2, newdata = newdata)
   expect_equal(dim(pred), c(2, 4))
+  
   # predictive error
   expect_equal(dim(predictive_error(fit1)), 
                c(Nsamples(fit1), nobs(fit1)))
+  
   # print
   expect_output(SW(print(fit1)), "Group-Level Effects:")
+  
   # prior_samples
   prs1 <- prior_samples(fit1)
   prior_names <- c("sds_sAge_1", "nu", "sd_visit", "b", "bmo", 
@@ -220,8 +262,10 @@ test_that("all S3 methods have reasonable ouputs", {
   prs2 <- prior_samples(fit1, pars = "b_Trt")
   expect_equal(dimnames(prs2), list(as.character(1:Nsamples(fit1)), "b_Trt"))
   expect_equal(sort(prs1$b), sort(prs2$b_Trt))
+  
   # prior_summary
   expect_true(is(prior_summary(fit1), "brmsprior"))
+  
   # ranef
   ranef1 <- ranef(fit1, estimate = "median", var = TRUE)
   expect_equal(dim(ranef1$visit), c(4, 2))
@@ -230,6 +274,7 @@ test_that("all S3 methods have reasonable ouputs", {
   ranef2 <- ranef(fit2, estimate = "mean", var = TRUE)
   expect_equal(dim(ranef2[[1]]), c(59, 1))
   expect_equal(dim(attr(ranef2[[1]], "var")), c(1, 1, 59))
+  
   # residuals
   res1 <- residuals(fit1, type = "pearson", probs = c(0.65))
   expect_equal(dim(res1), c(nobs(fit1), 3))
@@ -244,9 +289,14 @@ test_that("all S3 methods have reasonable ouputs", {
   
   res4 <- residuals(fit2)
   expect_equal(dim(res4), c(nobs(fit2), 4))
+  
+  expect_error(residuals(fit4), 
+               "Residuals not implemented for family 'sratio'")
+  
   # stancode
   expect_true(is.character(stancode(fit1)))
   expect_output(print(stancode(fit1)), "generated quantities")
+  
   # standata
   expect_equal(names(standata(fit1)),
                c("N", "Y", "nb_1", "knots_1", "Zs_1_1", "K", "X", 
@@ -257,6 +307,7 @@ test_that("all S3 methods have reasonable ouputs", {
                c("N", "Y", "KC", "C", "K_a", "X_a", "Z_1_a_1",
                  "K_b", "X_b", "Z_1_b_2", "J_1", "N_1", "M_1",
                  "NC_1", "disp", "prior_only"))
+  
   # stanplot tested in tests.plots.R
   # summary
   summary1 <- SW(summary(fit1, waic = TRUE, priors = TRUE))
@@ -274,6 +325,7 @@ test_that("all S3 methods have reasonable ouputs", {
   expect_output(print(summary1), "Priors:")
   
   summary2 <- SW(summary(fit1, waic = TRUE))
+  
   # update
   # do not actually refit the model as is causes CRAN checks to fail
   up <- update(fit1, testmode = TRUE)
@@ -303,6 +355,7 @@ test_that("all S3 methods have reasonable ouputs", {
   expect_true(is(up, "brmsfit"))
   up <- update(fit2, formula. = count ~ a + b, testmode = TRUE)
   expect_true(is(up, "brmsfit"))
+  
   # VarCorr
   vc <- VarCorr(fit1)
   expect_equal(names(vc), c("visit"))
@@ -318,23 +371,27 @@ test_that("all S3 methods have reasonable ouputs", {
   expect_equal(names(vc), c("patient"))
   data_vc <- as.data.frame(vc)
   expect_equal(dim(data_vc), c(2, 7))
+  
   # vcov
   expect_equal(dim(vcov(fit1)), c(8, 8))
   expect_equal(dim(vcov(fit1, cor = TRUE)), c(8, 8))
+  
   # WAIC
-  waic1 <- WAIC(fit1)
+  waic1 <- SW(WAIC(fit1))
   expect_true(is.numeric(waic1[["waic"]]))
   expect_true(is.numeric(waic1[["se_waic"]]))
-  expect_equal(waic1, waic(fit1))
+  expect_equal(waic1, SW(waic(fit1)))
   
-  waic_compare <- WAIC(fit1, fit1)
+  waic_compare <- SW(WAIC(fit1, fit1))
   expect_equal(length(waic_compare), 2)
   expect_equal(dim(attr(waic_compare, "compare")), c(1,2))
-  waic2 <- WAIC(fit2)
+  waic2 <- SW(WAIC(fit2))
   expect_true(is.numeric(waic2[["waic"]]))
-  waic_pointwise <- WAIC(fit2, pointwise = TRUE)
+  waic_pointwise <- SW(WAIC(fit2, pointwise = TRUE))
   expect_equal(waic2, waic_pointwise)
   expect_warning(WAIC(fit1, fit2), "Model comparisons are most likely invalid")
+  waic4 <- SW(WAIC(fit4))
+  expect_true(is.numeric(waic4[["waic"]]))
   
   # test diagnostic convenience functions
   expect_true(is(log_posterior(fit1), "data.frame"))
