@@ -19,20 +19,16 @@ test_that("rmNum remove all numeric entries", {
   expect_equal(rmNum(list(x = 1.5, y = "abc", z = pi)), list(y = "abc"))
 })
 
-test_that("forumla2string performs correct conversion", {
-  expect_equal(formula2string("y~x"), "y~x")
-  expect_equal(formula2string(y ~ x + c), "y~x+c")
-  expect_equal(formula2string(abc ~ x + cd, rm = c(3,2)), "~x+")
-})
-
 test_that("collapse_lists performs correct collapsing after names", {
   x <- list(a = "a <- ", b = "b <- ")
   y <- list(b = "cauchy(1,2)", c = "normal(0,1)", a = "gamma(1,1)")
   expect_equal(collapse_lists(list()), list())
   expect_equal(collapse_lists(list(x, y)), 
-               list(a = "a <- gamma(1,1)", b = "b <- cauchy(1,2)", c = "normal(0,1)"))
+               list(a = "a <- gamma(1,1)", b = "b <- cauchy(1,2)", 
+                    c = "normal(0,1)"))
   expect_equal(collapse_lists(list(c(x, c = "c <- "), y)),
-               list(a = "a <- gamma(1,1)", b = "b <- cauchy(1,2)", c = "c <- normal(0,1)"))
+               list(a = "a <- gamma(1,1)", b = "b <- cauchy(1,2)", 
+                    c = "c <- normal(0,1)"))
 })
 
 test_that("subset_attr works correctly", {
@@ -59,11 +55,6 @@ test_that("convenience functions for model families work correctly", {
   expect_true(use_int(binomial()))
   expect_true(has_trials("zero_inflated_binomial"))
   expect_true(has_cat("acat"))
-  expect_true(has_sigma(student()))
-  effects <- list(se = TRUE)
-  expect_true(!has_sigma("cauchy", effects = effects))
-  expect_true(has_sigma("cauchy", effects = effects, 
-                        autocor = cor_ar(cov = TRUE)))
 })
 
 test_that("use_alias works correctly", {
@@ -87,11 +78,6 @@ test_that("lsp works correctly", {
                c("log", "log10", "log1p", "log2", "logb", "logical"))
   expect_equal(lsp("brms", pattern = "^log_"),
                c("log_diff_exp", "log_inv_logit", 
-                 "log_lik.brmsfit", "log_sum_exp"))
+                 "log_lik.brmsfit", "log_posterior.brmsfit",
+                 "log_sum_exp"))
 })
-
-test_that(".addition and .cat works correctly", {
-  expect_equal(.addition(~ brms:::.cat(x), data = data.frame(x = 2:3)), 2:3)
-  expect_error(.addition(~ brms:::.cat(x), data = data.frame(x = -2)),
-               "number of categories must be positive integers")
-})
\ No newline at end of file
