@@ -4,7 +4,7 @@ test_that("check_prior performs correct renaming", {
                          set_prior("normal(0,1)", class = "b")),
                        formula = bf(rating ~ treat + (0 + treat +  carry | subject)), 
                        data = inhaler)
-  target <- prior_frame(prior = c("normal(0,1)", "lkj_corr_cholesky(0.5)"),
+  target <- brmsprior(prior = c("normal(0,1)", "lkj_corr_cholesky(0.5)"),
                         class = c("b", "L"), group = c("", "subject"))
   expect_true(length(which(duplicated(rbind(prior, target)))) == 2L)
   
@@ -13,7 +13,7 @@ test_that("check_prior performs correct renaming", {
                                    coef = "carry", nlpar = "rating")),
                        formula = bf(cbind(treat, rating) ~ 0 + carry), 
                        data = inhaler)
-  target <- prior_frame(prior = c("lkj_corr_cholesky(5)", "normal(0,1)"),
+  target <- brmsprior(prior = c("lkj_corr_cholesky(5)", "normal(0,1)"),
                         class = c("Lrescor", "b"), coef = c("", "carry"),
                         nlpar = c("", "rating")) 
   expect_true(length(which(duplicated(rbind(prior, target)))) == 2L)
@@ -21,25 +21,25 @@ test_that("check_prior performs correct renaming", {
   expect_equivalent(check_prior(set_prior("normal(0,1)", class = "Intercept"),
                                 formula = bf(rating ~ carry), data = inhaler, 
                                 family = cumulative())[3, ],
-                    prior_frame("normal(0,1)", class = "temp_Intercept"))
+                    brmsprior("normal(0,1)", class = "temp", coef = "Intercept"))
   
   expect_equivalent(check_prior(set_prior("normal(0,1)", class = "Intercept"),
                                 formula = bf(rating ~ carry), data = inhaler, 
                                 family = cumulative(),
                                 threshold = "equidistant")[4, ],
-                    prior_frame("normal(0,1)", class = "temp_Intercept"))
+                    brmsprior("normal(0,1)", class = "temp", coef = "Intercept"))
   
   expect_equivalent(check_prior(set_prior("normal(0,2)", "b", coef = "Intercept"),
                                 formula = bf(rating ~ carry), data = inhaler, 
                                 family = student())[5, ],
-                    prior_frame("normal(0,2)", class = "temp_Intercept"))
+                    brmsprior("normal(0,2)", class = "temp", coef = "Intercept"))
 })
 
 test_that("check_prior accepts correct prior names", {
   cp <- check_prior(c(set_prior("normal(0,1)", coef = "carry"),
                       set_prior("cauchy(1,1)", coef = "treat")),
                     formula = bf(rating ~ -1 + treat + carry), data = inhaler)
-  expect_equivalent(cp[2:3, ], prior_frame(c("normal(0,1)", "cauchy(1,1)"), 
+  expect_equivalent(cp[2:3, ], brmsprior(c("normal(0,1)", "cauchy(1,1)"), 
                                  class = "b", coef = c("carry", "treat")))
   
   cp <- check_prior(c(set_prior("p1", class = "sd", coef = "sexfemale", 
@@ -48,25 +48,25 @@ test_that("check_prior accepts correct prior names", {
                                 group = "patient")),
                     formula = bf(time ~ age + (sex+age|patient)),  
                     family = exponential(), data = kidney)
-  expect_equivalent(cp[9, ], prior_frame(prior = "p1", class = "sd", 
+  expect_equivalent(cp[9, ], brmsprior(prior = "p1", class = "sd", 
                                 coef = "sexfemale", group = "patient")[1, ])
   
   expect_equivalent(check_prior(set_prior("cauchy(0,1)", class = "sigma"), 
                                 formula = bf(rating ~ 1), family = gaussian(), 
                                 data = inhaler)[2, ],
-                    prior_frame("cauchy(0,1)", class = "sigma"))
+                    brmsprior("cauchy(0,1)", class = "sigma"))
   
   expect_equivalent(check_prior(c(set_prior("p1", class = "ar"),
                                   set_prior("p2", class = "ma")),
                                 formula = bf(count ~ Trt_c), data = epilepsy, 
                                 autocor = cor.arma(p = 1, q = 2))[c(1, 4), ],
-                    prior_frame(c("p1", "p2"), class = c("ar", "ma"),
+                    brmsprior(c("p1", "p2"), class = c("ar", "ma"),
                                 bound = "<lower=-1,upper=1>"))
   
   expect_equivalent(check_prior(set_prior("cauchy(0,1)", class = "sigmaLL"),
                                 formula = bf(count ~ Trt_c), data = epilepsy,
                                 autocor = cor_bsts())[4, ],
-                    prior_frame("cauchy(0,1)", class = "sigmaLL"))
+                    brmsprior("cauchy(0,1)", class = "sigmaLL"))
 })
 
 test_that("check_prior rejects incorrect prior names", {
@@ -88,7 +88,7 @@ test_that("check_prior returns increment_log_prob(.) whithout checking", {
                                   set_prior("p2", class = "b")),
                                 formula = bf(count ~ Trt_c), 
                                 data = epilepsy)[c(1, 5), ],
-                    prior_frame(c("p2", "increment_log_prob(p1)"), 
+                    brmsprior(c("p2", "increment_log_prob(p1)"), 
                                 class = c("b", "")))
 })
 
@@ -111,20 +111,30 @@ test_that("check_prior correctly validates priors for category specific effects"
              set_prior("cauchy(1,1)", class = "b", coef = "treat"))
   cp <- check_prior(prior, formula = bf(rating ~ 1 + cse(treat + carry)), 
                     data = inhaler, family = cratio())
-  target <- prior_frame(prior = c("normal(0,1)", "cauchy(1,1)"),
+  target <- brmsprior(prior = c("normal(0,1)", "cauchy(1,1)"),
                         class = "b", coef = c("carry", "treat"))
   expect_equivalent(cp[2:3, ], target)
 })
 
 test_that("check_prior correctly validates priors for monotonic effects", {
-  data <- data.frame(y = rpois(100, 10), x = rep(1:4, 25))
+  data <- data.frame(y = rpois(100, 10), x = rep(1:4, 25), 
+                     z = factor(rep(1:4, 25), ordered = TRUE))
   prior <- c(set_prior("normal(0,1)", class = "b", coef = "x"),
-             set_prior("dirichlet(c(1,0.5,2))", class = "simplex", coef = "x"))
-  cp <- check_prior(prior, formula = bf(y ~ monotonic(x)), data = data,
-                    family = poisson())
-  target <- prior_frame(prior = c("normal(0,1)", "dirichlet(c(1,0.5,2))"),
-                        class = c("b", "simplex"), coef = c("x", "x"))
+             set_prior("dirichlet(c(1,0.5,2))", "simplex", coef = "x"),
+             set_prior("dirichlet(c(1,0.5,2))", "simplex", coef = "z"))
+  
+  cp <- check_prior(prior, formula = bf(y ~ monotonic(x)), 
+                    data = data, family = poisson())
+  target <- brmsprior(prior = c("normal(0,1)", "dirichlet(c(1,0.5,2))"),
+                      class = c("b", "simplex"), coef = c("x", "x"))
   expect_equivalent(cp[2:3, ], target)
+  
+  cp <- check_prior(prior, formula = bf(y ~ monotonic(z)), 
+                    data = data, family = poisson())
+  target <- brmsprior(prior = "dirichlet(c(1,0.5,2))", 
+                      class = "simplex", coef = "z")
+  expect_equivalent(cp[3, ], target)
+  
   expect_error(check_prior(set_prior("beta(1,1)", class = "simplex", coef = "x"), 
                            formula = bf(y ~ monotonic(x)), data = data),
                "'dirichlet' is the only valid prior for simplex parameters")
@@ -132,12 +142,13 @@ test_that("check_prior correctly validates priors for monotonic effects", {
 
 test_that("handle_special_priors handles horseshoe prior correctly", {
   prior <- set_prior("horseshoe(5)")
-  temp <- handle_special_priors(c(prior))
-  expect_equal(temp$attrib$hs_df, 5)
-  expect_equal(temp$prior$prior[1], "normal(0, hs_local * hs_global)")
-  expect_error(handle_special_priors(c(prior, set_prior("dist()", coef = "a"))))
-  expect_error(handle_special_priors(c(set_prior("horseshoe(b5)"))),
-               "degrees of freedom of horseshoe prior must be a positive")
+  prior <- handle_special_priors(c(prior))
+  expect_equal(attr(prior, "hs_df"), 5)
+  expect_equal(prior$prior[1], "normal(0, hs_local * hs_global)")
+  expect_error(handle_special_priors(c(set_prior("horseshoe(-1)"))),
+               "Degrees of freedom of the local priors")
+  expect_error(handle_special_priors(c(set_prior("horseshoe(1, -1)"))),
+               "Scale of the global prior")
 })
 
 test_that("get_prior finds all classes for which priors can be specified", {
@@ -223,3 +234,12 @@ test_that("check_prior_content returns expected errors and warnings", {
   prior <- c(set_prior("normal(0,2)", class = "ar", lb = "0"))
   expect_warning(check_prior_content(prior), "autocorrelation parameters")
 })
+
+test_that("set_prior alias functions produce equivalent results", {
+  expect_equal(set_prior("normal(0, 1)", class = "sd"),
+               prior(normal(0, 1), class = sd))
+  expect_equal(set_prior("normal(0, 1)", class = "sd", nlpar = "a"),
+               prior(normal(0, 1), class = "sd", nlpar = a))
+  expect_equal(set_prior("normal(0, 1)", class = "sd"),
+               prior_string("normal(0, 1)", class = "sd"))
+})
